@@ -180,8 +180,7 @@ void help(void) {
 
 void help_online(void) {
     endwin();
-    if (debug) system("less help.txt");
-    else system("less /usr/local/share/sel/help.txt");
+    system("/usr/bin/sensible-pager /usr/share/sel/help.txt");
 }
 
 void display_settings(void) {
